#### Apollo standard script #####

library(apollo) # Load apollo package 

# Remove crazy outliers for testing the model 
database <- database_full %>% filter(Rent_SQ <= 10000, WalkingDistance_SQ <= 300)

# Test treatment effect

# Define cut time

cut_time <- 15

database <- database %>%
  filter(!is.na(Treatment_new)) %>%
  mutate(groupTime1774 = case_when(is.na(groupTime1774) ~0, TRUE~groupTime1774),
         groupTime1784 = case_when(is.na(groupTime1784) ~0, TRUE~groupTime1784)) %>%  # remove NAs for interaction
  filter(groupTime1774 <= 3600) %>% 
  mutate(Treatment_group_time = case_when(groupTime1774 > 0 & groupTime1774 < cut_time & 
                                          groupTime1784 < 120 ~ 1, # Not read or watch Info
                                          groupTime1774 >= cut_time & groupTime1784 < 120 ~ 2, # Text No Video
                                          groupTime1774 >= cut_time & groupTime1784 >= 120 ~ 3, # Text and Video
                                          groupTime1774 < cut_time & groupTime1784 >= 120 ~ 4, # No Text but Video
                                          TRUE ~ 0)) %>%  
  mutate(Dummy_NT_NV = case_when(Treatment_group_time == 1 ~ 1, TRUE~0),
         Dummy_Text_NV = case_when(Treatment_group_time == 2 ~ 1, TRUE ~0),
         Dummy_Text_VD = case_when(Treatment_group_time == 3 ~ 1, TRUE ~0),
         Dummy_NT_VD = case_when(Treatment_group_time == 4 ~ 1, TRUE ~0))


table(database$Treatment_group_time)

ggplot(data=database) +
  geom_bar(aes(x=Treatment_group_time,
               group=as.factor(Treatment_group_time), fill=as.factor(Treatment_group_time))) +
  xlab("Treatment Group") +
  ylab("Count") + 
  labs(fill="Treatment Group") 

ggsave("Figures/treatment_time_groups.png", width=7, height = 5, dpi="print")

  #initialize model 
  
  apollo_initialise()
  
  
  ### Set core controls
  apollo_control = list(
    modelName  = "MXL_wtp_time_groups",
    modelDescr = "MXL wtp space grouped by time",
    indivID    ="id",
    mixing     = TRUE,
    HB= FALSE,
    nCores     = n_cores, 
    outputDirectory = "Estimation_results/mxl"
  )
  
  ##### Define model parameters depending on your attributes and model specification! ####
  # set values to 0 for conditional logit model
  
  apollo_beta=c(mu_natural = 15,
                mu_walking = -1,
                mu_rent = -2,
                ASC_sq = 0,
                mu_nat_notext_nv = 0,
                mu_nat_text_nv =0,
                mu_nat_notext_vd = 0,
                mu_nat_text_vd = 0,
                sig_natural = 15,
                sig_walking = 2,
                sig_rent = 2)
  
  ### specify parameters that should be kept fixed, here = none
  apollo_fixed = c()
  
  ### Set parameters for generating draws, use 2000 sobol draws
  apollo_draws = list(
    interDrawsType = "sobol",
    interNDraws    = n_draws,
    interUnifDraws = c(),
    interNormDraws = c("draws_natural", "draws_walking", "draws_rent"),
    intraDrawsType = "halton",
    intraNDraws    = 0,
    intraUnifDraws = c(),
    intraNormDraws = c()
  )
  
  ### Create random parameters, define distribution of the parameters
  apollo_randCoeff = function(apollo_beta, apollo_inputs){
    randcoeff = list()
    
    randcoeff[["b_mu_natural"]] = mu_natural + sig_natural * draws_natural
    randcoeff[["b_mu_walking"]] = mu_walking + sig_walking * draws_walking
    randcoeff[["b_mu_rent"]] = -exp(mu_rent + sig_rent * draws_rent)
    
    return(randcoeff)
  }
  
  
  ### validate 
  apollo_inputs = apollo_validateInputs()
  apollo_probabilities=function(apollo_beta, apollo_inputs, functionality="estimate"){
    
    ### Function initialisation: do not change the following three commands
    ### Attach inputs and detach after function exit
    apollo_attach(apollo_beta, apollo_inputs)
    on.exit(apollo_detach(apollo_beta, apollo_inputs))
    
    ### Create list of probabilities P
    P = list()
    
    #### List of utilities (later integrated in mnl_settings below)  ####
    # Define utility functions here:
     
    V = list()
    V[['alt1']] = -b_mu_rent*(b_mu_natural * Naturalness_1 + b_mu_walking * WalkingDistance_1 + 
                                mu_nat_text_nv * Dummy_Text_NV * Naturalness_1 + mu_nat_notext_vd * Dummy_NT_VD * Naturalness_1 +
                                mu_nat_text_vd * Dummy_Text_VD * Naturalness_1 + mu_nat_notext_nv * Dummy_NT_NV * Naturalness_1 
                                - Rent_1)
    
    V[['alt2']] = -b_mu_rent*(b_mu_natural * Naturalness_2 + b_mu_walking * WalkingDistance_2 +
                                mu_nat_text_nv * Dummy_Text_NV * Naturalness_2 + mu_nat_notext_vd * Dummy_NT_VD * Naturalness_2 +
                                mu_nat_text_vd * Dummy_Text_VD * Naturalness_2 + mu_nat_notext_nv * Dummy_NT_NV * Naturalness_2  
                                - Rent_2)
    
    V[['alt3']] = -b_mu_rent*(ASC_sq + b_mu_natural * Naturalness_3 + b_mu_walking * WalkingDistance_3 + 
                                mu_nat_text_nv * Dummy_Text_NV * Naturalness_3 + mu_nat_notext_vd * Dummy_NT_VD * Naturalness_3 +
                                mu_nat_text_vd * Dummy_Text_VD * Naturalness_3 + mu_nat_notext_nv * Dummy_NT_NV * Naturalness_3  
                                - Rent_3)
    
    
    ### Define settings for MNL model component
    mnl_settings = list(
      alternatives  = c(alt1=1, alt2=2, alt3=3),
      avail         = 1, # all alternatives are available in every choice
      choiceVar     = choice,
      V             = V#,  # tell function to use list vector defined above
      
    )
    
    ### Compute probabilities using MNL model
    P[['model']] = apollo_mnl(mnl_settings, functionality)
    
    ### Take product across observation for same individual
    P = apollo_panelProd(P, apollo_inputs, functionality)
    
    ### Average across inter-individual draws - nur bei Mixed Logit!
    P = apollo_avgInterDraws(P, apollo_inputs, functionality)
    
    ### Prepare and return outputs of function
    P = apollo_prepareProb(P, apollo_inputs, functionality)
    return(P)
  }
  
  
  
  # ################################################################# #
  #### MODEL ESTIMATION                                            ##
  # ################################################################# #
  # estimate model with bfgs algorithm
  
  mxl_wtp_time_groups = apollo_estimate(apollo_beta, apollo_fixed,
                        apollo_probabilities, apollo_inputs, 
                        estimate_settings=list(maxIterations=400,
                                               estimationRoutine="bfgs",
                                               hessianRoutine="analytic"))
  
  
  
  # ################################################################# #
  #### MODEL OUTPUTS                                               ##
  # ################################################################# #
  apollo_saveOutput(mxl_wtp_time_groups)


